stats_consolidation
-------------------

Statistics consolidation scripts for XO rrd generated files.


Summary
~~~~~~~

Implement a software module for reading RRD files stored on School servers,
process the data and save into a Relational Database.


Install instructions
~~~~~~~~~~~~~~~~~~~~

See INSTALL.


Resources
~~~~~~~~~

http://wiki.sugarlabs.org/go/Sugar_Server_Kit/sugar-server
